"""
Prompt templates package for langvio
"""

from langvio.prompts.templates import (
    EXPLANATION_TEMPLATE,
    QUERY_PARSING_TEMPLATE,
    SYSTEM_PROMPT,
)

__all__ = ["QUERY_PARSING_TEMPLATE", "EXPLANATION_TEMPLATE", "SYSTEM_PROMPT"]
